summaryrefslogtreecommitdiffstats
path: root/kate/part/katetextline.h
diff options
context:
space:
mode:
Diffstat (limited to 'kate/part/katetextline.h')
-rw-r--r--kate/part/katetextline.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kate/part/katetextline.h b/kate/part/katetextline.h
index 3922d04d0..84df82908 100644
--- a/kate/part/katetextline.h
+++ b/kate/part/katetextline.h
@@ -145,10 +145,10 @@ class KateTextLine : public KShared
inline TQChar getChar (uint pos) const { return m_text[pos]; }
/**
* Gets the text as a unicode representation
* @return text of this line as TQChar array
*/
- inline const TQChar *text() const { return m_text.unicode(); }
+ inline const TQChar *text() const { return m_text.tqunicode(); }
/**
* Highlighting array
@@ -419,7 +419,7 @@ class KateTextLine : public KShared
*/
private:
/**
* text of line as unicode
*/
TQString m_text;
@@ -145,10 +145,10 @@ class KateTextLine : public KShared
inline TQChar getChar (uint pos) const { return m_text[pos]; }
/**
- * Gets the text as a unicode representation
+ * Gets the text as a tqunicode representation
* @return text of this line as TQChar array
*/
@@ -419,7 +419,7 @@ class KateTextLine : public KShared
private:
/**
- * text of line as unicode
+ * text of line as tqunicode
*/
TQString m_text;